/*
 * Ionic ioNious app.
 */

(function(){
    'use strict';

    /* Revealing pattern: */
    angular.module('ionious', ['ionic'])
        .run(runFnct)
        .config(confFnct)
        .controller('NwsCtrl', ['$scope', '$http', '$ionicScrollDelegate', NwsCtrl])

    /*
     * Startup function.
     */
    function runFnct($ionicPlatform) {
        $ionicPlatform.ready(function() {
            /* Hide the accessory bar by default (remove this to show the accessory bar above the keyboard for form inputs) */
            if (window.cordova && window.cordova.plugins.Keyboard) {
                cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
                cordova.plugins.Keyboard.disableScroll(true);
            }
            if (window.StatusBar) {
                // org.apache.cordova.statusbar required
                StatusBar.styleDefault();
            }
        });
    }

    /*
     * Config function.
     */
    function confFnct($stateProvider, $urlRouterProvider) {
        $stateProvider
            .state('app', {
                url: '/app',
                abstract: true
            })
            .state('splash', {
                url: '/splash',
                templateUrl: 'templates/splash.html'
            })
            .state('nws', {
                url: '/nws',
                templateUrl: 'templates/nws.html'
            })

        /* If none of the above states are matched, use this as the fallback */
        $urlRouterProvider.otherwise('/splash');
    }

    /*
     * Main controller.
     */
    function NwsCtrl($scope, $http, $ionicScrollDelegate) {

        /* Get RSS feeds URLs */
        $scope.feeds = {};
        $http.get("data/rss-feeds.json")
            .then(function(response) {
                $scope.feeds = response.data;
                //console.log($scope.feeds);
            });

        $scope.news = [];

        $scope.title = "Latest Nious";
        $scope.url = "";
        //$scope.url = (navigator.onLine) ? "http://rss2json.com/api.json?rss_url=http://klnavarro.fr/blog/spip.php?page=backend" : "data/news.json";

        /* Refresh latest news (accessed by ion-sidemenu or ion-refresher) */
        $scope.refreshNews = function(title,url) {
            if (!url) {  /* nothing to refresh */
                /* Stop the ion-refresher from spinning (if any) */
                $scope.$broadcast('scroll.refreshComplete');
                return;
            }
            $scope.loaded = false;
            $scope.news = [];
            $scope.title = title;
            $scope.url = url;
            //console.log("refreshing "+title+"("+url+")...");
            $ionicScrollDelegate.scrollTop(true);  /* return top of list */
            $http.get("http://rss2json.com/api.json?rss_url=" + $scope.url)  /* reload news */
                .then(function(response) {  //.success
                    //console.log(response);
                    if (response.data.status == "ok") {
                        $scope.news = response.data.items;
                    }
                    else {  /* error: make fake item with error msg */
                        $scope.news = [ {"title":"Error: rss2json",
                                         "link":"",
                                         "description":response.data.errorMessage,
                                         "enclosure":{"link":"",
                                                      "type":"image\/jpeg",
                                                      "length":0} } ];
                    }
                    $scope.loaded = true;
                })
                .finally(function() {
                    /* Stop the ion-refresher from spinning */
                    $scope.$broadcast('scroll.refreshComplete');
                });
        }

        /* Test if item is starred as favorite? */
        $scope.isFav = function(item) {
            var match = $scope.favorites.filter(function(fav) {
                return fav.title == item.title;
            });
            return match.length;
        }

        /* Show favorites */
        $scope.showFavorites = function() {
            $scope.loaded = false;
            $scope.title = "Favorites";
            $scope.url = "";
            //console.log("loading Favorites...");
            $scope.news = $scope.favorites;  /* load favorites */
            $ionicScrollDelegate.scrollTop(true);  /* return top of list */
            $scope.loaded = true;
        }

        /* Add to favorites */
        $scope.like = function(item) {
            if ($scope.isFav(item)) {
                return;  // already present
            }
            $scope.favorites.push(item);
            localStorage.setItem('NIOUSFAV', JSON.stringify($scope.favorites));
            //console.log($scope.favorites);
        }

        /* Remove from favorites */
        $scope.unlike = function(item) {
            if ($scope.isFav(item) == 0) {
                return;  // not found
            }
            var idx = $scope.favorites.indexOf(item);
            $scope.favorites.splice(idx, 1);
            localStorage.setItem('NIOUSFAV', JSON.stringify($scope.favorites));
            //console.log($scope.favorites);
            if (!$scope.url) {  /* refresh forced on favorites view */
                $scope.showFavorites();
            }
        }

        /* Load favorites from localStorage */
        $scope.favorites = JSON.parse(localStorage.getItem('NIOUSFAV')) || [];
        $scope.showFavorites();  /* by default show favorites */

    }

})() // IIFE
